import pendulum
from . import models, schemas
from .database import Database
from sqlalchemy import delete, update, select, text, func, or_, and_
from sqlalchemy.orm import sessionmaker

db = Database()
Session = sessionmaker(db.engine)


def create_categorie(categorie_name: str):
    with Session() as session:
        db_categorie = schemas.Categories(
            name=categorie_name,
        )
        session.add(db_categorie)
        session.commit()
        return True


def create_point(point: models.Points):
    with Session() as session:
        point_schema = schemas.Points(
            id_categories=point.id_categories, geolocalisation=point.geolocalisation
        )
        session.add(point_schema)
        session.commit()
        return True


def is_categorie_exist(categorie_name: str):
    with Session() as session:
        return (
            session.query(schemas.Categories).filter_by(name=categorie_name).first()
            is not None
        )


def get_categorie(categorie_name):
    with Session() as session:
        return session.query(schemas.Categories).filter_by(name=categorie_name).first()


def create_vigilo_categories(categorie: models.VigiloCategories):
    with Session() as session:
        categorie_schema = schemas.VigiloCategories(
            id=categorie.id, name=categorie.name
        )
        session.add(categorie_schema)
        session.commit()
        return True


def is_vigilo_categories_exists(categorie: models.VigiloCategories):
    with Session() as session:
        return (
            session.query(schemas.VigiloCategories).filter_by(id=categorie.id).first()
            is not None
        )


def is_vigilo_observation_exists(observation: models.VigiloObservations):
    with Session() as session:
        return (
            session.query(schemas.VigiloObservations)
            .filter_by(id=observation.id)
            .first()
            is not None
        )


def get_vigilo(category: int):
    today = pendulum.today("Europe/Paris")
    six_months_ago = today.subtract(months=6)
    with Session() as session:
        return (
            session.query(schemas.VigiloObservations)
            .where(
                and_(
                    schemas.VigiloObservations.vigilo_categories_id == category,
                    schemas.VigiloObservations.datetime < six_months_ago,
                    or_(
                        schemas.VigiloObservations.comment.like("%cyclable%"),
                        schemas.VigiloObservations.comment.like("%cycliste%"),
                        schemas.VigiloObservations.comment.like("%piste%"),
                        schemas.VigiloObservations.comment.like("%BC"),
                        schemas.VigiloObservations.comment.like("%racine%"),
                        schemas.VigiloObservations.comment.like("%haie%"),
                    ),
                )
            )
            .all()
        )


def get_all_communes():
    with Session() as session:
        return session.query(schemas.CommuneNM).all()


def create_vigilo_observation(observation: models.VigiloObservations):
    with Session() as session:
        data_observation = schemas.VigiloObservations(
            id=observation.id,
            vigilo_categories_id=observation.vigilo_categories_id,
            datetime=observation.datetime,
            geolocalisation=observation.geolocalisation,
            comment=observation.comment,
        )
        session.add(data_observation)
        session.commit()
        return True


def get_raw_onisr_value():
    # statement = text("""
    # SELECT DISTINCT("onisr_2021_lieux"."Num_Acc"), "onisr_2021_usagers"."grav", "onisr_2021_vehicules"."obsm", "onisr_2021_vehicules"."catv", "onisr_2021_vehicules"."num_veh", "onisr_2021_caracteristiques"."int", "onisr_2021_caracteristiques"."jour",  "onisr_2021_caracteristiques"."mois", "onisr_2021_caracteristiques"."an", "onisr_2021_caracteristiques"."hrmn", "onisr_2021_caracteristiques"."lat", "onisr_2021_caracteristiques"."long"
    # FROM onisr_2021_lieux
    # JOIN onisr_2021_caracteristiques on "onisr_2021_caracteristiques"."Num_Acc" = "onisr_2021_lieux"."Num_Acc"
    # JOIN onisr_2021_usagers on "onisr_2021_usagers"."Num_Acc" = "onisr_2021_lieux"."Num_Acc"
    # JOIN onisr_2021_vehicules on "onisr_2021_vehicules"."Num_Acc" = "onisr_2021_lieux"."Num_Acc"
    # WHERE "onisr_2021_vehicules"."catv" IN (1,60) AND "onisr_2021_usagers"."secu1" != 1 AND "onisr_2021_usagers"."secu1" != -1;
    # """)
    statement = text(
        """
    SELECT DISTINCT("onisr_2022_lieux"."Num_Acc"), "onisr_2022_usagers"."grav", "onisr_2022_vehicules"."obsm", "onisr_2022_vehicules"."catv", "onisr_2022_vehicules"."num_veh", "onisr_2022_caracteristiques"."int", "onisr_2022_caracteristiques"."jour",  "onisr_2022_caracteristiques"."mois", "onisr_2022_caracteristiques"."an", "onisr_2022_caracteristiques"."hrmn", "onisr_2022_caracteristiques"."lat", "onisr_2022_caracteristiques"."long"
    FROM onisr_2022_lieux
    JOIN onisr_2022_caracteristiques on "onisr_2022_caracteristiques"."Num_Acc" = "onisr_2022_lieux"."Num_Acc"
    JOIN onisr_2022_usagers on "onisr_2022_usagers"."Num_Acc" = "onisr_2022_lieux"."Num_Acc"
    JOIN onisr_2022_vehicules on "onisr_2022_vehicules"."Num_Acc" = "onisr_2022_lieux"."Num_Acc"
    WHERE "onisr_2022_vehicules"."catv" IN (1,80) AND "onisr_2022_usagers"."secu1" != 1 AND "onisr_2022_usagers"."secu1" != -1;
    """
    )
    with Session() as session:
        data = session.execute(statement)
        return data


def add_onisr_processed(onisr_data: models.OnisrProcessedCreate):
    with Session() as session:
        onisr = schemas.Onisr_2022_Processed(
            accident_id=onisr_data.accident_id,
            gravite=onisr_data.gravite,
            obstacle_mobile=onisr_data.obstacle_mobile,
            categorie_vehicule=onisr_data.categorie_vehicule,
            numero_vehicule=onisr_data.numero_vehicule,
            intersection=onisr_data.intersection,
            datetime=onisr_data.datetime,
            geolocalisation=onisr_data.geolocalisation,
        )
        session.add(onisr)
        session.commit()
        return True


def get_all_onisr_2022():
    with Session() as session:
        return session.query(schemas.Onisr_2022_Processed).all()


def get_all_onisr_2021():
    with Session() as session:
        return session.query(schemas.Onisr_2021_Processed).all()


def drop_unmetre():
    statement = text(
        """
    DROP TABLE IF EXISTS un_metre;
    """
    )
    with Session() as session:
        data = session.execute(statement)
        return data


def get_unmetre_points(where_clause: str = "WHERE distance_overtaker <= 0.5"):
    statement = text(
        f"""
    SELECT ogc_fid, wkb_geometry FROM un_metre {where_clause};
    """
    )
    with Session() as session:
        data = session.execute(statement).all()
        return data
