from sqlalchemy import (
    Column,
    Integer,
    BigInteger,
    Date,
    Numeric,
    String,
    DateTime,
    ForeignKey,
    func,
    Boolean,
)
from sqlalchemy.orm import declarative_base
from geoalchemy2 import Geometry

Base = declarative_base()


class Categories(Base):
    __tablename__ = "categories"

    id = Column(Integer, primary_key=True)
    name = Column(String)


class Points(Base):
    __tablename__ = "points"

    id = Column(Integer, primary_key=True)
    id_categories = Column(Integer, ForeignKey("categories.id"))
    geolocalisation = Column(Geometry("POINT"))


class CommuneNM(Base):
    __tablename__ = "commune_nm"
    objectid = Column("OBJECTID", Numeric)
    code_commune = Column("Code commune", Numeric)
    identifiant_insee = Column("Identifiant INSEE", Numeric)
    update_date = Column("Date de mise à jour", Date)
    commune = Column("Commune", String)
    toponyme = Column("Toponyme", String)
    id_comm = Column("id_comm", Numeric, primary_key=True)


class VigiloCategories(Base):
    __tablename__ = "vigilo_categories"
    id = Column(Integer, primary_key=True)
    name = Column(String)


class VigiloObservations(Base):
    __tablename__ = "vigilo_observations"
    id = Column(String, primary_key=True)
    vigilo_categories_id = Column(Integer, ForeignKey("vigilo_categories.id"))
    geolocalisation = Column(Geometry("POINT"))
    datetime = Column("datetime", DateTime(timezone=True), default=func.now())
    comment = Column(String)


class UnMetre(Base):
    __tablename__ = "un_metre"
    id = Column(Integer, primary_key=True)
    geolocalisation = Column(Geometry("POINT"))
    datetime = Column("datetime", DateTime(timezone=True), default=func.now())


class Onisr_2021_Processed(Base):
    __tablename__ = "onisr_2021_processed"
    id = Column(BigInteger, primary_key=True)
    accident_id = Column(BigInteger)
    gravite = Column(Integer)
    obstacle_mobile = Column(Integer)
    categorie_vehicule = Column(Integer)
    numero_vehicule = Column(String)
    intersection = Column(Numeric)
    datetime = Column("datetime", DateTime(timezone=True), default=func.now())
    geolocalisation = Column(Geometry("POINT"))


class Onisr_2022_Processed(Base):
    __tablename__ = "onisr_2022_processed"
    id = Column(BigInteger, primary_key=True)
    accident_id = Column(BigInteger)
    gravite = Column(Integer)
    obstacle_mobile = Column(Integer)
    categorie_vehicule = Column(Integer)
    numero_vehicule = Column(String)
    intersection = Column(Numeric)
    datetime = Column("datetime", DateTime(timezone=True), default=func.now())
    geolocalisation = Column(Geometry("POINT"))
